Reads a cmsg from a buffer
This function will
- advance the buffer by the used space
- return the used space, the cmsg header, and the data buffer
Returns an error if no message could be read from the buffer.
See also the crate documentation.