Function uapi::cmsg_space
source · pub const fn cmsg_space(data_len: usize) -> usizeExpand description
Returns the number of bytes needed to store a cmsg with data-length data_len
See also the crate documentation.
pub const fn cmsg_space(data_len: usize) -> usizeReturns the number of bytes needed to store a cmsg with data-length data_len
See also the crate documentation.