Function uapi::msghdr_control_none_ref
source · [−]Expand description
Returns Option::<&[u8]>::None
This is useful for functions or structures which are generic over the control message
type and whose type cannot be inferred if None is used on its own.