Function uapi::pod_zeroed
source · [−]pub fn pod_zeroed<T: Pod>() -> TExpand description
Returns an instance of T whose object representation is 0 in all non-padding bytes
pub fn pod_zeroed<T: Pod>() -> TReturns an instance of T whose object representation is 0 in all non-padding bytes