Function uapi::sockaddr_none_mut [−][src]
Returns Option::<&mut c::sockaddr>::None
This is useful for functions or structures which are generic over the sockaddr type
and whose type cannot be inferred if None is used on its own.