[−][src]Struct uapi::OwnedFd
An owned file descriptor
Upon Drop, the contained file descriptor will be closed.
Errors from close() are ignored.
The contained file descriptor can be accessed via deref: *self.
This struct can be converted From and Into various std types.
Implementations
impl OwnedFd[src]
pub fn new(raw: c_int) -> OwnedFd[src]
pub fn borrow(&self) -> Fd[src]
Shortcut for Fd::new(*self)
pub fn unwrap(self) -> c_int[src]
Returns *self and does not run Drop
pub fn raw(&self) -> c_int[src]
Returns *self