pub struct UtsName { /* fields omitted */ }
Wrapper for libc::utsname
Returns self.sysname as a CStr
Returns self.nodename as a CStr
Returns self.release as a CStr
Returns self.version as a CStr
Returns self.machine as a CStr
The resulting type after dereferencing.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.