NlmsgHeaderExt

Trait NlmsgHeaderExt 

pub trait NlmsgHeaderExt: NlmsgHeader + Sealed {
    // Provided method
    fn read<'a>(buf: &mut &'a [u8]) -> Result<(usize, Self, &'a [u8])>
       where Self: Pod { ... }
}
👎Deprecated: beta features are subject to change at any time
Extension trait for netlink message headers

See also the crate documentation.

Provided Methods

fn read<'a>(buf: &mut &'a [u8]) -> Result<(usize, Self, &'a [u8])>
where Self: Pod,

👎Deprecated: beta features are subject to change at any time

Reads a header plus payload from a netlink message

Returns the space consumed, the header, and the payload.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors