Trait uapi::Pod

source · []
pub unsafe trait Pod { }
Marker trait for Pod types

This is not a general Pod type and only supposed to be used for interaction with this crate.

See also the crate documentation.

Safety

For all sized types T: Pod, transmuting any array of type [u8; size_of::<T>()] to T must produce a valid value.

For all types T: Pod, overwriting the contents of t: &mut T with any array of type [u8; size_of_val(t)] must produce a valid value.

Implementations on Foreign Types

Implementors