pub unsafe trait SockAddr: Pod { }Expand description
Marker trait for socket address types
Safety
If a type T implements this trait then it must be one of the socket types supported
by the operating system.
pub unsafe trait SockAddr: Pod { }Marker trait for socket address types
If a type T implements this trait then it must be one of the socket types supported
by the operating system.