Trait uapi::NlmsgHeader
source · [−]pub trait NlmsgHeader: Sized {
fn len(&self) -> Result<usize>;
fn set_len(&mut self, len: usize) -> Result<()>;
}👎 Deprecated:
beta features are subject to change at any time
The general shape of a header of a netlink message
Note that this is not the same as c::nlmsghdr.
See also the crate documentation.
Required Methods
👎 Deprecated:
beta features are subject to change at any time
Returns the length of the padded header + payload
This function returns an error if the length cannot be converted to usize
without truncation.