Trait uapi::SockAddr[][src]

pub unsafe trait SockAddr: Pod { }
Marker trait for socket address types

Safety

If a type T implements this trait then it must be one of the socket types supported by the operating system.

Implementors